( cd usr/lib/terminfo/h ; rm -rf hp70092a )
( cd usr/lib/terminfo/h ; ln -sf  hp70092 hp70092a )
( cd usr/lib/terminfo/h ; rm -rf hp70092A )
( cd usr/lib/terminfo/h ; ln -sf  hp70092 hp70092A )
( cd usr/lib/terminfo/p ; rm -rf pc3 )
( cd usr/lib/terminfo/p ; ln -sf  pc pc3 )
( cd usr/lib/terminfo/p ; rm -rf pccons )
( cd usr/lib/terminfo/p ; ln -sf  pc pccons )
( cd usr/lib/terminfo/v ; rm -rf vt100-am )
( cd usr/lib/terminfo/v ; ln -sf  vt100 vt100-am )
( cd usr/lib/terminfo/v ; rm -rf vt100am )
( cd usr/lib/terminfo/v ; ln -sf  vt100 vt100am )
( cd usr/lib/terminfo/v ; rm -rf vt220 )
( cd usr/lib/terminfo/v ; ln -sf  vt200 vt220 )
( cd usr/lib/terminfo/v ; rm -rf vt200-js )
( cd usr/lib/terminfo/v ; ln -sf  vt200 vt200-js )
( cd usr/lib/terminfo/v ; rm -rf vt220-js )
( cd usr/lib/terminfo/v ; ln -sf  vt200 vt220-js )
( cd usr/lib/terminfo/v ; rm -rf vt320 )
( cd usr/lib/terminfo/v ; ln -sf  vt300 vt320 )
( cd usr/lib/terminfo/v ; rm -rf vs100s )
( cd usr/lib/terminfo/v ; ln -sf  vs100 vs100s )
( cd usr/lib/terminfo/x ; rm -rf xterm-vi )
( cd usr/lib/terminfo/x ; ln -sf  xterm-ic xterm-vi )
( cd usr/lib/terminfo/x ; rm -rf xterm )
( cd usr/lib/terminfo/x ; ln -sf  ../v/vs100 xterm )
( cd usr/lib/terminfo/7 ; rm -rf 70092 )
( cd usr/lib/terminfo/7 ; ln -sf  ../h/hp70092 70092 )
( cd usr/lib/terminfo/7 ; rm -rf 70092A )
( cd usr/lib/terminfo/7 ; ln -sf  ../h/hp70092A 70092A )
( cd usr/lib/terminfo/7 ; rm -rf 70092a )
( cd usr/lib/terminfo/7 ; ln -sf  ../h/hp70092a 70092a )
( cd usr/include/ncurses ; rm -rf curses.h )
( cd usr/include/ncurses ; ln -sf  ncurses.h curses.h )
